==> comfyui_embedded_docs-0.2.0-py3-none-any.whl: comfyui_embedded_docs/docs/InpaintModelConditioning/en.md <==

The InpaintModelConditioning node is designed to facilitate the conditioning process for inpainting models, enabling the integration and manipulation of various conditioning inputs to tailor the inpainting output. It encompasses a broad range of functionalities, from loading specific model checkpoints and applying style or control net models, to encoding and combining conditioning elements, thereby serving as a comprehensive tool for customizing inpainting tasks.
## Input types
| Parameter | Comfy dtype        | Description |
|-----------|--------------------|-------------|
| `positive`| `CONDITIONING`     | Represents the positive conditioning information or parameters that are to be applied to the inpainting model. This input is crucial for defining the context or constraints under which the inpainting operation should be performed, affecting the final output significantly. |
| `negative`| `CONDITIONING`     | Represents the negative conditioning information or parameters that are to be applied to the inpainting model. This input is essential for specifying the conditions or contexts to avoid during the inpainting process, thereby influencing the final output. |
| `vae`     | `VAE`              | Specifies the VAE model to be used in the conditioning process. This input is crucial for determining the specific architecture and parameters of the VAE model that will be utilized. |
| `pixels`  | `IMAGE`            | Represents the pixel data of the image to be inpainted. This input is essential for providing the visual context necessary for the inpainting task. |
| `mask`    | `MASK`             | Specifies the mask to be applied to the image, indicating the areas to be inpainted. This input is crucial for defining the specific regions within the image that require inpainting. |

## Output types

| Parameter | Comfy dtype  | Description |
|-----------|--------------|-------------|
| `positive`| `CONDITIONING` | The modified positive conditioning information after processing, ready to be applied to the inpainting model. This output is essential for guiding the inpainting process according to the specified positive conditions. |
| `negative`| `CONDITIONING` | The modified negative conditioning information after processing, ready to be applied to the inpainting model. This output is essential for guiding the inpainting process according to the specified negative conditions. |
| `latent`  | `LATENT`     | The latent representation derived from the conditioning process. This output is crucial for understanding the underlying features and characteristics of the image being inpainted. |

==> comfyui_embedded_docs-0.2.3-py3-none-any.whl: comfyui_embedded_docs/docs/InpaintModelConditioning/en.md <==
The InpaintModelConditioning node is designed to facilitate the conditioning process for inpainting models, enabling the integration and manipulation of various conditioning inputs to tailor the inpainting output. It encompasses a broad range of functionalities, from loading specific model checkpoints and applying style or control net models, to encoding and combining conditioning elements, thereby serving as a comprehensive tool for customizing inpainting tasks.

## Inputs

| Parameter | Comfy dtype        | Description |
|-----------|--------------------|-------------|
| `positive`| `CONDITIONING`     | Represents the positive conditioning information or parameters that are to be applied to the inpainting model. This input is crucial for defining the context or constraints under which the inpainting operation should be performed, affecting the final output significantly. |
| `negative`| `CONDITIONING`     | Represents the negative conditioning information or parameters that are to be applied to the inpainting model. This input is essential for specifying the conditions or contexts to avoid during the inpainting process, thereby influencing the final output. |
| `vae`     | `VAE`              | Specifies the VAE model to be used in the conditioning process. This input is crucial for determining the specific architecture and parameters of the VAE model that will be utilized. |
| `pixels`  | `IMAGE`            | Represents the pixel data of the image to be inpainted. This input is essential for providing the visual context necessary for the inpainting task. |
| `mask`    | `MASK`             | Specifies the mask to be applied to the image, indicating the areas to be inpainted. This input is crucial for defining the specific regions within the image that require inpainting. |

## Outputs

| Parameter | Data Type | Description |
|-----------|--------------|-------------|
| `positive`| `CONDITIONING` | The modified positive conditioning information after processing, ready to be applied to the inpainting model. This output is essential for guiding the inpainting process according to the specified positive conditions. |
| `negative`| `CONDITIONING` | The modified negative conditioning information after processing, ready to be applied to the inpainting model. This output is essential for guiding the inpainting process according to the specified negative conditions. |
| `latent`  | `LATENT`     | The latent representation derived from the conditioning process. This output is crucial for understanding the underlying features and characteristics of the image being inpainted. |
